package com.diagbot.facade;

import com.diagbot.biz.push.entity.Item;
import com.diagbot.biz.push.entity.Lis;
import com.diagbot.biz.push.entity.Pacs;
import com.diagbot.client.StandConvertServiceClient;
import com.diagbot.dto.IndicationDTO;
import com.diagbot.dto.StandConvertCrfBatchDTO;
import com.diagbot.dto.StandConvertCrfDTO;
import com.diagbot.util.ExcelUtils;
import com.diagbot.util.ListUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.Drug;
import com.diagbot.vo.IndicationPushVO;
import com.diagbot.vo.ItemExt;
import com.diagbot.vo.StandConvertCrfVO;
import com.diagbot.vo.TestIndicationVO;
import com.diagbot.vo.TestLineVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description: 测试facade
 * @author: zhoutg
 * @time: 2018/8/6 9:11
 */
@Component
public class TestFacade {

    @Autowired
    IndicationFacade indicationFacade;
    @Autowired
    StandConvertServiceClient standConvertServiceClient;

    /**
     * 开单项数据测试
     *
     * @param file
     */
    public Map<String, Object> importExcel(MultipartFile file, TestLineVO testLineVO) {
        List<IndicationPushVO> indicationPushVOList = new ArrayList<>();
        List<TestIndicationVO> data = ExcelUtils.importExcelMultiSheets(file, 0, 1, testLineVO.getSheetIndex(), TestIndicationVO.class);
        for (TestIndicationVO bean : data) {
            if (StringUtil.isNotEmpty(testLineVO.getIdNum()) && !testLineVO.getIdNum().equals(bean.getIdNum())) {
                continue;
            }
            IndicationPushVO indicationPushVO = new IndicationPushVO();
            indicationPushVO.setRuleType("2");
            indicationPushVO.setIdNum(bean.getIdNum());
            if (StringUtil.isNotBlank(bean.getOrderType())) {
                switch (bean.getOrderType()) {
                    case "实验室检查名称": // 细项
                        List<Lis> lisDetailOrder = new ArrayList<>();
                        Lis lisDetailBean = new Lis();
                        lisDetailBean.setName(bean.getStandName());
                        lisDetailBean.setDetailName(bean.getStandName());
                        lisDetailBean.setUniqueName(bean.getStandName());
                        lisDetailOrder.add(lisDetailBean);
                        indicationPushVO.setLisOrder(lisDetailOrder);
                        break;
                    case "辅助检查名称":
                        List<Pacs> pacsOrder = new ArrayList<>();
                        Pacs pacsBean = new Pacs();
                        pacsBean.setName(bean.getStandName());
                        pacsBean.setUniqueName(bean.getStandName());
                        pacsOrder.add(pacsBean);
                        indicationPushVO.setPacsOrder(pacsOrder);
                        break;
                    case "实验室检查套餐名":
                        List<Lis> lisOrder = new ArrayList<>();
                        Lis lisBean = new Lis();
                        lisBean.setName(bean.getStandName());
                        lisBean.setUniqueName(bean.getStandName());
                        lisOrder.add(lisBean);
                        indicationPushVO.setLisOrder(lisOrder);
                        break;
                    case "医保手术和操作名称":
                        List<Item> operationOrder = new ArrayList<>();
                        Item operationItem = new Item();
                        operationItem.setName(bean.getStandName());
                        operationItem.setUniqueName(bean.getStandName());
                        operationOrder.add(operationItem);
                        indicationPushVO.setOperationOrder(operationOrder);
                        break;
                    default:
                        continue;
                }
            }

            if (StringUtil.isNotEmpty(bean.getNeoType())) {
                switch (bean.getNeoType()) {
                    // case "1" : // 性别
                    //     if ("男性".equals(bean.getNeoName())) {
                    //         indicationPushVO.setSex(1);
                    //     } else if ("女性".equals(bean.getNeoName())) {
                    //         indicationPushVO.setSex(2);
                    //     }
                    //     break;
                    // case "2" : // 化验, 示例：血小板计数，＜，50，10^9/L
                    //     String lisStr = bean.getNeoName();
                    //     String[] lisArr = lisStr.split("，");
                    //
                    //     List<Lis> lisList = new ArrayList<>();
                    //     Lis lisBean = new Lis();
                    //     lisBean.setUniqueName(lisArr[0]);
                    //     lisBean.setName(lisArr[0]);
                    //     lisBean.setDetailName(lisArr[0]);
                    //     lisBean.setValue(getValue(lisArr));
                    //     lisList.add(lisBean);
                    //     indicationPushVO.setLis(lisList);
                    //     break;
                    // case "3" : // 临床表现
                    //     indicationPushVO.setChief(bean.getNeoName());
                    //     break;
                    // case "4": //辅助检查描述
                    //     indicationPushVO.setSymptom("B超:提示"+bean.getNeoName());
                    //     break;
                    // case "5" : // 诊断
                    //     List<Item> diag = new ArrayList<>();
                    //     Item diagItem = new Item();
                    //     diagItem.setName(bean.getNeoName());
                    //     diagItem.setUniqueName(bean.getNeoName());
                    //     diag.add(diagItem);
                    //     indicationPushVO.setDiag(diag);
                    //     break;
                    // case "6" : // 服用药品
                    //     StringBuffer symptom = new StringBuffer("发病来，神志清，精神可，胃纳一般，睡眠可，二便无殊。一直服用");
                    //     symptom.append(bean.getNeoName()).append("。");
                    //     indicationPushVO.setSymptom(symptom.toString());
                    //     break;
                    // case "12": // 体征
                    //    StringBuffer sbVital = new StringBuffer();
                    //    String[] vitalArr = bean.getNeoName().split("，");
                    //    if (vitalArr.length > 1) {
                    //        if ("收缩压".equals(vitalArr[0]) || "舒张压".equals(vitalArr[0])) {
                    //            if ("收缩压".equals(vitalArr[0])) {
                    //                sbVital.append("血压");
                    //                sbVital.append(getValue(vitalArr) + "/100mmHg");
                    //                indicationPushVO.setVital(sbVital.toString());
                    //            } else if ("舒张压".equals(vitalArr[0])) {
                    //                sbVital.append("血压");
                    //                sbVital.append("100/" + getValue(vitalArr) + "mmHg");
                    //                indicationPushVO.setVital(sbVital.toString());
                    //            }
                    //        } else {
                    //            // 其他数值类型
                    //            sbVital.append(vitalArr[0]);
                    //            sbVital.append(getValue(vitalArr));
                    //            sbVital.append(vitalArr[3]);
                    //            indicationPushVO.setVital(sbVital.toString());
                    //        }
                    //    } else {
                    //        sbVital.append(vitalArr[0]);
                    //        indicationPushVO.setVital(sbVital.toString());
                    //    }
                    //    break;
                    // default:
                    //     continue;
                }
            }
            indicationPushVOList.add(indicationPushVO);
        }

        Map<String, Object> map = new LinkedHashMap<>();

        List<String> msg = new ArrayList<>();
        List<String> errMsg = new ArrayList<>();
        for (IndicationPushVO indicationPushVO : indicationPushVOList) {
            try {
                IndicationDTO indicationDTO = indicationFacade.indicationFac(indicationPushVO);
                if (ListUtil.isEmpty(indicationDTO.getBillMsgList())) {
                    msg.add("第【" + indicationPushVO.getIdNum() + "】行未匹配");
                }
            } catch (Exception e) {
                System.out.println(indicationPushVO.getIdNum() + "行出错了!" + e.getMessage());
                errMsg.add(indicationPushVO.getIdNum() + "行出错了");
            }
        }
        map.put("总条数", indicationPushVOList.size() + "条");
        map.put("出错条数", msg.size() + "条");
        map.put("出错信息", msg);
        map.put("程序报错", errMsg);
        return map;
    }

    /**
     * 开单项数据测试——输血
     *
     * @param file
     */
    public Map<String, Object> testIndicationTransfusion(MultipartFile file, TestLineVO testLineVO) {
        List<IndicationPushVO> indicationPushVOList = new ArrayList<>();
        List<TestIndicationVO> data = ExcelUtils.importExcelMultiSheets(file, 0, 1, testLineVO.getSheetIndex(), TestIndicationVO.class);
        for (TestIndicationVO bean : data) {
            if (StringUtil.isNotEmpty(testLineVO.getIdNum()) && !testLineVO.getIdNum().equals(bean.getIdNum())) {
                continue;
            }
            if (StringUtil.isBlank(bean.getTransfusionNodeName())) {
                continue;
            }
            IndicationPushVO indicationPushVO = new IndicationPushVO();
            indicationPushVO.setRuleType("2");
            indicationPushVO.setIdNum(bean.getIdNum());
            if (StringUtil.isNotBlank(bean.getTransfusionName())) {
                List<ItemExt> transfusionOrder = new ArrayList<>();
                ItemExt item = new ItemExt();
                item.setName(bean.getTransfusionName());
                item.setUniqueName(bean.getTransfusionName());
                transfusionOrder.add(item);
                indicationPushVO.setTransfusionOrder(transfusionOrder);
            }

            if (StringUtil.isNotEmpty(bean.getTransfusionNodeName())) {
                switch (bean.getTransfusionNodeName()) {
                    case "手术和操作": // 手术和操作
                        List<Item> operation = new ArrayList<>();
                        Item item = new Item();
                        item.setName(bean.getStandName());
                        item.setUniqueName(bean.getStandName());
                        operation.add(item);
                        indicationPushVO.setOperation(operation);
                        break;
                    case "医保疾病名称": // 医保疾病名称
                        List<Item> diag = new ArrayList<>();
                        Item itemDiag = new Item();
                        itemDiag.setName(bean.getStandName());
                        itemDiag.setUniqueName(bean.getStandName());
                        diag.add(itemDiag);
                        indicationPushVO.setDiag(diag);
                        break;
                    case "实验室检查": // 实验室检查
                        List<Lis> lisList = new ArrayList<>();
                        Lis lisBean = new Lis();
                        lisBean.setUniqueName(bean.getStandName());
                        lisBean.setName(bean.getStandName());
                        lisBean.setDetailName(bean.getStandName());
                        lisBean.setValue(getValue(bean.getSymbol(), bean.getValue()));
                        lisList.add(lisBean);
                        indicationPushVO.setLis(lisList);
                        break;
                    default:
                        continue;
                }
            }
            indicationPushVOList.add(indicationPushVO);
        }

        Map<String, Object> map = new LinkedHashMap<>();

        List<String> msg = new ArrayList<>();
        List<String> errMsg = new ArrayList<>();
        for (IndicationPushVO indicationPushVO : indicationPushVOList) {
            try {
                IndicationDTO indicationDTO = indicationFacade.indicationFac(indicationPushVO);
                if (ListUtil.isEmpty(indicationDTO.getBillMsgList())) {
                    msg.add("第【" + indicationPushVO.getIdNum() + "】行未匹配");
                }
            } catch (Exception e) {
                System.out.println(indicationPushVO.getIdNum() + "行出错了!" + e.getMessage());
                errMsg.add(indicationPushVO.getIdNum() + "行出错了");
            }
        }
        map.put("总条数", indicationPushVOList.size() + "条");
        map.put("出错条数", msg.size() + "条");
        map.put("出错信息", msg);
        map.put("程序报错", errMsg);
        return map;
    }

    /**
     * 高危手术测试API
     *
     * @param file
     */
    public Map<String, Object> testHighRiskOperationExcel(MultipartFile file, TestLineVO testLineVO) {
        List<IndicationPushVO> indicationPushVOList = new ArrayList<>();
        List<TestIndicationVO> data = ExcelUtils.importExcelMultiSheets(file, 0, 1, testLineVO.getSheetIndex(), TestIndicationVO.class);
        for (TestIndicationVO bean : data) {
            if (StringUtil.isNotEmpty(testLineVO.getIdNum()) && !testLineVO.getIdNum().equals(bean.getIdNum())) {
                continue;
            }
            // 3,4是高危手术
            if ("0" .equals(bean.getOperationLevel()) || "1" .equals(bean.getOperationLevel()) || "2" .equals(bean.getOperationLevel())) {
                continue;
            }
            IndicationPushVO indicationPushVO = new IndicationPushVO();
            indicationPushVO.setRuleType("3");
            indicationPushVO.setIdNum(bean.getIdNum());
            List<Item> operationOrder = new ArrayList<>();
            Item item = new Item();
            item.setUniqueName(bean.getOperationName());
            item.setName(bean.getOperationName());
            operationOrder.add(item);
            indicationPushVO.setOperationOrder(operationOrder);
            indicationPushVOList.add(indicationPushVO);
        }

        Map<String, Object> map = new LinkedHashMap<>();

        List<String> msg = new ArrayList<>();
        List<String> errMsg = new ArrayList<>();
        for (IndicationPushVO indicationPushVO : indicationPushVOList) {
            try {
                IndicationDTO indicationDTO = indicationFacade.indicationFac(indicationPushVO);
                if (ListUtil.isEmpty(indicationDTO.getHighRiskList())) {
                    msg.add("第【" + indicationPushVO.getIdNum() + "】行未匹配");
                }
            } catch (Exception e) {
                System.out.println(e.getMessage());
                errMsg.add(indicationPushVO.getIdNum() + "行出错了");
            }
        }
        map.put("总条数", indicationPushVOList.size() + "条");
        map.put("出错条数", msg.size() + "条");
        map.put("出错信息", msg);
        map.put("程序报错", errMsg);
        return map;
    }

    /**
     * 其他值提醒测试——化验
     *
     * @param file
     */
    public Map<String, Object> testOtherTipLis(MultipartFile file, TestLineVO testLineVO) {
        List<IndicationPushVO> indicationPushVOList = new ArrayList<>();
        List<TestIndicationVO> data = ExcelUtils.importExcelMultiSheets(file, 0, 1, testLineVO.getSheetIndex(), TestIndicationVO.class);
        for (TestIndicationVO bean : data) {
            if (StringUtil.isNotEmpty(testLineVO.getIdNum()) && !testLineVO.getIdNum().equals(bean.getIdNum())) {
                continue;
            }
            IndicationPushVO indicationPushVO = new IndicationPushVO();
            indicationPushVO.setRuleType("4");
            indicationPushVO.setIdNum(bean.getIdNum());

            if ("药品通用名称" .equals(bean.getOtherTipNodeType())) {
                List<Drug> drug = new ArrayList<>();
                Drug item = new Drug();
                item.setUniqueName(bean.getOtherTipNodeName());
                item.setName(bean.getOtherTipNodeName());
                drug.add(item);
                indicationPushVO.setDrug(drug);
            } else if ("医保疾病名称" .equals(bean.getOtherTipNodeType())) {
                List<Item> diag = new ArrayList<>();
                Item item = new Item();
                item.setUniqueName(bean.getOtherTipNodeName());
                item.setName(bean.getOtherTipNodeName());
                diag.add(item);
                indicationPushVO.setDiag(diag);
            }
            List<Lis> lisList = new ArrayList<>();
            Lis lis = new Lis();
            lis.setName("套餐");
            lis.setDetailName("明细");
            lis.setUniqueName(bean.getOtherTipLisName());
            lis.setValue(getValue(bean.getSymbol(), bean.getValue()));
            lisList.add(lis);
            indicationPushVO.setLis(lisList);
            indicationPushVOList.add(indicationPushVO);
        }

        Map<String, Object> map = new LinkedHashMap<>();

        List<String> msg = new ArrayList<>();
        List<String> errMsg = new ArrayList<>();
        for (IndicationPushVO indicationPushVO : indicationPushVOList) {
            try {
                IndicationDTO indicationDTO = indicationFacade.indicationFac(indicationPushVO);
                if (ListUtil.isEmpty(indicationDTO.getOtherList())) {
                    msg.add("第【" + indicationPushVO.getIdNum() + "】行未匹配");
                }
            } catch (Exception e) {
                System.out.println(e.getMessage());
                errMsg.add(indicationPushVO.getIdNum() + "行出错了");
            }
        }
        map.put("总条数", indicationPushVOList.size() + "条");
        map.put("出错条数", msg.size() + "条");
        map.put("出错信息", msg);
        map.put("程序报错", errMsg);
        return map;
    }

    /**
     * 其他值提醒测试——辅检
     *
     * @param file
     */
    public Map<String, Object> testOtherTipPacs(MultipartFile file, TestLineVO testLineVO) {
        List<IndicationPushVO> indicationPushVOList = new ArrayList<>();
        List<TestIndicationVO> data = ExcelUtils.importExcelMultiSheets(file, 0, 1, testLineVO.getSheetIndex(), TestIndicationVO.class);
        for (TestIndicationVO bean : data) {
            if (StringUtil.isNotEmpty(testLineVO.getIdNum()) && !testLineVO.getIdNum().equals(bean.getIdNum())) {
                continue;
            }
            IndicationPushVO indicationPushVO = new IndicationPushVO();
            indicationPushVO.setRuleType("4");
            indicationPushVO.setIdNum(bean.getIdNum());

            if ("男性" .equals(bean.getSexStr())) {
                indicationPushVO.setSex(1);
            } else if ("女性" .equals(bean.getSexStr())) {
                indicationPushVO.setSex(2);
            }
            if (StringUtil.isNotBlank(bean.getDisName())) {
                List<Item> diag = new ArrayList<>();
                Item item = new Item();
                item.setUniqueName(bean.getDisName());
                item.setName(bean.getDisName());
                diag.add(item);
                indicationPushVO.setDiag(diag);
            }
            if (bean.getAgeRange() != null) {
                if (bean.getAgeRange() == 0) {
                    if (bean.getAgeMin() != null) {
                        indicationPushVO.setAge(bean.getAgeMin() + 1);
                    } else if (bean.getAgeMax() != null) {
                        indicationPushVO.setAge(bean.getAgeMin() - 1);
                    }
                } else if (bean.getAgeRange() == 1) {
                    if (bean.getAgeMin() != null) {
                        indicationPushVO.setAge(bean.getAgeMin() - 1);
                    } else if (bean.getAgeMax() != null) {
                        indicationPushVO.setAge(bean.getAgeMax() + 1);
                    }
                }
            }
            if (StringUtil.isNotBlank(bean.getPacsDesc())) {
                Pacs pacs = new Pacs();
                pacs.setName("胸部CT");
                pacs.setUniqueName("胸部CT");
                pacs.setResult(bean.getPacsDesc());
                indicationPushVO.getPacs().add(pacs);
            }

            if (StringUtil.isNotBlank(bean.getPacsDescHas())) {
                Pacs pacs = new Pacs();
                pacs.setName("CT");
                pacs.setUniqueName("CT");
                pacs.setResult(bean.getPacsDescHas());
                indicationPushVO.getPacs().add(pacs);
            }

            indicationPushVOList.add(indicationPushVO);
        }

        Map<String, Object> map = new LinkedHashMap<>();

        List<String> msg = new ArrayList<>();
        List<String> errMsg = new ArrayList<>();
        for (IndicationPushVO indicationPushVO : indicationPushVOList) {
            try {
                IndicationDTO indicationDTO = indicationFacade.indicationFac(indicationPushVO);
                if (ListUtil.isEmpty(indicationDTO.getOtherList())) {
                    msg.add("第【" + indicationPushVO.getIdNum() + "】行未匹配");
                }
            } catch (Exception e) {
                System.out.println(e.getMessage());
                errMsg.add(indicationPushVO.getIdNum() + "行出错了");
            }
        }
        map.put("总条数", indicationPushVOList.size() + "条");
        map.put("出错条数", msg.size() + "条");
        map.put("出错信息", msg);
        map.put("程序报错", errMsg);
        return map;
    }

    /**
     * 其他值提醒测试——输血
     *
     * @param file
     */
    public Map<String, Object> testOtherTipTransfusion(MultipartFile file, TestLineVO testLineVO) {
        List<IndicationPushVO> indicationPushVOList = new ArrayList<>();
        List<TestIndicationVO> data = ExcelUtils.importExcelMultiSheets(file, 0, 1, testLineVO.getSheetIndex(), TestIndicationVO.class);
        for (TestIndicationVO bean : data) {
            if (StringUtil.isNotEmpty(testLineVO.getIdNum()) && !testLineVO.getIdNum().equals(bean.getIdNum())) {
                continue;
            }
            IndicationPushVO indicationPushVO = new IndicationPushVO();
            indicationPushVO.setRuleType("4");
            indicationPushVO.setIdNum(bean.getIdNum());

            if (StringUtil.isNotBlank(bean.getDisName())) {
                List<Item> diag = new ArrayList<>();
                Item item = new Item();
                item.setUniqueName(bean.getDisName());
                item.setName(bean.getDisName());
                diag.add(item);
                indicationPushVO.setDiag(diag);
            }
            if (StringUtil.isNotBlank(bean.getOperationName())) {
                List<Item> operation = new ArrayList<>();
                Item item = new Item();
                item.setUniqueName(bean.getOperationName());
                item.setName(bean.getOperationName());
                operation.add(item);
                indicationPushVO.setOperation(operation);
            }
            if ("实验室检查名称" .equals(bean.getItemNodeName())) {
                List<Lis> lisList = new ArrayList<>();
                Lis lis = new Lis();
                lis.setName("套餐");
                lis.setDetailName("明细");
                lis.setUniqueName(bean.getItemName());
                lis.setValue(getValue(bean.getSymbol(), bean.getValue()));
                lisList.add(lis);
                indicationPushVO.setLis(lisList);
                indicationPushVOList.add(indicationPushVO);
            }
        }

        Map<String, Object> map = new LinkedHashMap<>();
        List<String> msg = new ArrayList<>();
        List<String> errMsg = new ArrayList<>();
        for (IndicationPushVO indicationPushVO : indicationPushVOList) {
            try {
                IndicationDTO indicationDTO = indicationFacade.indicationFac(indicationPushVO);
                if (ListUtil.isEmpty(indicationDTO.getOtherList())) {
                    msg.add("第【" + indicationPushVO.getIdNum() + "】行未匹配");
                }
            } catch (Exception e) {
                System.out.println(e.getMessage());
                errMsg.add(indicationPushVO.getIdNum() + "行出错了");
            }
        }
        map.put("总条数", indicationPushVOList.size() + "条");
        map.put("出错条数", msg.size() + "条");
        map.put("出错信息", msg);
        map.put("程序报错", errMsg);
        return map;
    }

    /**
     * 高危药品测试API
     *
     * @param file
     */
    public Map<String, Object> testHighRiskDrugExcel(MultipartFile file, TestLineVO testLineVO) {
        List<IndicationPushVO> indicationPushVOList = new ArrayList<>();
        List<TestIndicationVO> data = ExcelUtils.importExcelMultiSheets(file, 0, 1, testLineVO.getSheetIndex(), TestIndicationVO.class);
        for (TestIndicationVO bean : data) {
            if (StringUtil.isNotEmpty(testLineVO.getIdNum()) && !testLineVO.getIdNum().equals(bean.getIdNum())) {
                continue;
            }
            if (StringUtil.isEmpty(bean.getDrugLevel())) {
                continue;
            }
            IndicationPushVO indicationPushVO = new IndicationPushVO();
            indicationPushVO.setRuleType("3");
            indicationPushVO.setIdNum(bean.getIdNum());
            List<Drug> drug = new ArrayList<>();
            Drug item = new Drug();
            item.setUniqueName(bean.getDrugHighRisk());
            item.setName(bean.getDrugHighRisk());
            item.setForm(bean.getDrugForm());
            drug.add(item);
            indicationPushVO.setDrug(drug);
            indicationPushVOList.add(indicationPushVO);
        }

        Map<String, Object> map = new LinkedHashMap<>();

        List<String> msg = new ArrayList<>();
        List<String> errMsg = new ArrayList<>();
        for (IndicationPushVO indicationPushVO : indicationPushVOList) {
            try {
                IndicationDTO indicationDTO = indicationFacade.indicationFac(indicationPushVO);
                if (ListUtil.isEmpty(indicationDTO.getHighRiskList())) {
                    msg.add("第【" + indicationPushVO.getIdNum() + "】行未匹配");
                }
            } catch (Exception e) {
                System.out.println(e.getMessage());
                errMsg.add(indicationPushVO.getIdNum() + "行出错了");
            }
        }
        map.put("总条数", indicationPushVOList.size() + "条");
        map.put("出错条数", msg.size() + "条");
        map.put("出错信息", msg);
        map.put("程序报错", errMsg);
        return map;
    }

    /**
     * 危急值数据测试
     *
     * @param file
     */
    public Map<String, Object> importCriticalExcel(MultipartFile file, TestLineVO testLineVO) {
        List<IndicationPushVO> indicationPushVOList = new ArrayList<>();
        List<TestIndicationVO> data = ExcelUtils.importExcelMultiSheets(file, 0, 1, testLineVO.getSheetIndex(), TestIndicationVO.class);
        for (TestIndicationVO bean : data) {
            if (StringUtil.isNotEmpty(testLineVO.getIdNum()) && !testLineVO.getIdNum().equals(bean.getIdNum())) {
                continue;
            }
            IndicationPushVO indicationPushVO = new IndicationPushVO();
            indicationPushVO.setRuleType("1");
            if (StringUtil.isNotBlank(bean.getCriticalAge()) && "成人" .equals(bean.getCriticalAge())) {
                indicationPushVO.setAge(20);
            } else if (StringUtil.isNotBlank(bean.getCriticalAge()) && "新生儿" .equals(bean.getCriticalAge())) {
                indicationPushVO.setAge(1);
            } else {
                indicationPushVO.setAge(20);
            }
            indicationPushVO.setSex(1);
            indicationPushVO.setIdNum(bean.getIdNum());

            List<Lis> lisDetail = new ArrayList<>();
            if (bean.getCriticalMin() != null) {
                Lis lisDetailBean = new Lis();
                lisDetailBean.setName(bean.getCriticalMeal());
                lisDetailBean.setDetailName(bean.getCriticalLis());
                lisDetailBean.setUniqueName(bean.getCriticalLis());
                lisDetailBean.setValue(bean.getCriticalMin());
                lisDetail.add(lisDetailBean);
            } else if (bean.getCriticalMax() != null) {
                Lis lisDetailBean = new Lis();
                lisDetailBean.setName(bean.getCriticalMeal());
                lisDetailBean.setDetailName(bean.getCriticalLis());
                lisDetailBean.setUniqueName(bean.getCriticalLis());
                lisDetailBean.setValue(bean.getCriticalMax());
                lisDetail.add(lisDetailBean);
            }
            indicationPushVO.setLis(lisDetail);

            indicationPushVOList.add(indicationPushVO);
        }

        Map<String, Object> map = new LinkedHashMap<>();

        List<String> msg = new ArrayList<>();
        List<String> errMsg = new ArrayList<>();
        for (IndicationPushVO indicationPushVO : indicationPushVOList) {
            try {
                IndicationDTO indicationDTO = indicationFacade.indicationFac(indicationPushVO);
                if (ListUtil.isEmpty(indicationDTO.getCriticalValList())) {
                    msg.add("第【" + indicationPushVO.getIdNum() + "】行未匹配");
                }
            } catch (Exception e) {
                System.out.println(e.getMessage());
                errMsg.add(indicationPushVO.getIdNum() + "行出错了");
            }
        }
        map.put("总条数", indicationPushVOList.size() + "条");
        map.put("出错条数", msg.size() + "条");
        map.put("出错信息", msg);
        map.put("程序报错", errMsg);
        return map;
    }

    /**
     * 返回数值
     *
     * @param arr
     * @return
     */
    public double getValue(String[] arr) {
        if ("＜" .equals(arr[1]) || "≤" .equals(arr[1]) || "<" .equals(arr[1]) || "≤" .equals(arr[1])) {
            return Double.parseDouble(arr[2]) - 0.1;
        } else if ("＞" .equals(arr[1]) || "≥" .equals(arr[1]) || (">").equals(arr[1])) {
            return Double.parseDouble(arr[2]) + 0.1;
        }
        return 0.0;
    }

    /**
     * 返回数值
     *
     * @param arr
     * @return
     */
    public double getValueNum(String[] arr) {
        if ("＜" .equals(arr[1]) || "≤" .equals(arr[1])) {
            return Double.parseDouble(arr[2]) - 1;
        } else if ("＞" .equals(arr[1]) || "≥" .equals(arr[1])) {
            return Double.parseDouble(arr[2]) + 1;
        }
        return 0.0;
    }

    /**
     * 返回数值
     *
     * @param dou
     * @return
     */
    public double getValue(String symbol, Double dou) {
        if ("＜" .equals(symbol) || "≤" .equals(symbol)) {
            return dou - 0.1;
        } else if ("＞" .equals(symbol) || "≥" .equals(symbol)) {
            return dou + 0.1;
        }
        return 0.0;
    }

    /**
     * 标准词转换
     *
     * @param standConvertCrfVO
     * @return
     */
    public StandConvertCrfDTO testStandConvert(StandConvertCrfVO standConvertCrfVO) {
        StandConvertCrfDTO standConvertCrfDTO = standConvertServiceClient.similarity(standConvertCrfVO);
        return standConvertCrfDTO;
    }

    /**
     * 标准词转换(批量)
     *
     * @param standConvertCrfVOList
     * @return
     */
    public StandConvertCrfBatchDTO testStandConvertBatch(List<StandConvertCrfVO> standConvertCrfVOList) {
        StandConvertCrfBatchDTO standConvertCrfBatchDTO = standConvertServiceClient.similarityBatch(standConvertCrfVOList);
        return standConvertCrfBatchDTO;
    }

    public Map<String, Object> testHighRiskProcess(MultipartFile file, TestLineVO testLineVO) {
        List<IndicationPushVO> indicationPushVOList = new ArrayList<>();
        List<TestIndicationVO> data = ExcelUtils.importExcelMultiSheets(file, 0, 1, testLineVO.getSheetIndex(), TestIndicationVO.class);
        for (TestIndicationVO bean : data) {
            if (StringUtil.isNotEmpty(testLineVO.getIdNum()) && !testLineVO.getIdNum().equals(bean.getIdNum())) {
                continue;
            }
            // 3,4是高危手术
            if ("0" .equals(bean.getOperationLevel()) || "1" .equals(bean.getOperationLevel())
                    || "3" .equals(bean.getOperationLevel()) || "4" .equals(bean.getOperationLevel())) {
                continue;
            }
            IndicationPushVO indicationPushVO = new IndicationPushVO();
            //年龄
            String[] split = bean.getAgeAll().split(",");
            indicationPushVO.setAge((int) getValueNum(split));
            indicationPushVO.setRuleType("3");
            indicationPushVO.setIdNum(bean.getIdNum());
            List<Item> operationOrder = new ArrayList<>();
            //体格
            String physique = bean.getPhysique();
            String[] physiqueStrArray = physique.split("，");
            for (String str : physiqueStrArray) {
                if (str.contains(",")) {
                    //包含英文逗号
                    String[] strArray = str.split(",");
                    String t = strArray[0] + getValue(strArray) + strArray[3];
                    indicationPushVO.setVital(t);
                    break;
                } else {
                    indicationPushVO.setVital(str);
                    break;
                }
            }
            //化验
            String lisAll = bean.getLisAll();
            String[] physiquelisAll = lisAll.split("，");
            List<Lis> lisList = new ArrayList<>();
            for (String str : physiquelisAll) {
                if (str.contains(",")) {
                    //包含英文逗号
                    String[] strArray = str.split(",");
                    String lisStr = bean.getNeoName();
                    Lis lisBean = new Lis();
                    lisBean.setUniqueName(strArray[0]);
                    lisBean.setName(strArray[0]);
                    lisBean.setDetailName(strArray[0]);
                    lisBean.setValue(getValue(strArray));
                    lisList.add(lisBean);
                    indicationPushVO.setLis(lisList);
                    break;
                } else {
                    indicationPushVO.setVital(str);
                    break;
                }
            }
            //辅检
            String pacsAll = bean.getPacsAll();
            String[] physiquepacsAll = pacsAll.split("，");
            indicationPushVO.setSymptom("B超:提示" + pacsAll);
            List<Pacs> pacs = new ArrayList<>();
            for (String pacsStr : physiquepacsAll) {
                Pacs pacs1 = new Pacs();
                pacs1.setUniqueName("腹部CT");
                pacs1.setName("腹部CT");
                pacs1.setResult(pacsStr);
                pacs.add(pacs1);
                break;
            }
            indicationPushVO.setPacs(pacs);
            //诊断"腹部CT"
            String disease = bean.getDisease();
            String[] physiquedisease = pacsAll.split("，");
            List<Item> diag = new ArrayList<>();
            for (String diseaseStr : physiquedisease) {
                Item item = new Item();
                item.setUniqueName(diseaseStr);
                item.setName(diseaseStr);
                diag.add(item);
                break;
            }
            indicationPushVO.setDiag(diag);
            Item item = new Item();
            item.setUniqueName(bean.getOperationName());
            item.setName(bean.getOperationName());
            operationOrder.add(item);
            indicationPushVO.setOperationOrder(operationOrder);
            indicationPushVOList.add(indicationPushVO);
        }

        Map<String, Object> map = new LinkedHashMap<>();
        List<String> msg = new ArrayList<>();
        List<String> errMsg = new ArrayList<>();
        for (IndicationPushVO indicationPushVO : indicationPushVOList) {
            try {
                IndicationDTO indicationDTO = indicationFacade.indicationFac(indicationPushVO);
                if (ListUtil.isEmpty(indicationDTO.getHighRiskList())) {
                    msg.add("第【" + indicationPushVO.getIdNum() + "】行未匹配");
                }
            } catch (Exception e) {
                System.out.println(e.getMessage());
                errMsg.add(indicationPushVO.getIdNum() + "行出错了");
            }
        }
        map.put("总条数", indicationPushVOList.size() + "条");
        map.put("出错条数", msg.size() + "条");
        map.put("出错信息", msg);
        map.put("程序报错", errMsg);
        return map;
    }
}
