package com.diagbot.process;

import com.diagbot.biz.push.entity.Item;
import com.diagbot.biz.push.entity.Lis;
import com.diagbot.dto.BillMsg;
import com.diagbot.dto.HighRiskNeoDTO;
import com.diagbot.dto.IndicationDTO;
import com.diagbot.dto.NodeNeoDTO;
import com.diagbot.dto.WordCrfDTO;
import com.diagbot.enums.TypeEnum;
import com.diagbot.model.label.PacsLabel;
import com.diagbot.model.label.VitalLabel;
import com.diagbot.rule.CommonRule;
import com.diagbot.util.CoreUtil;
import com.diagbot.util.MsgUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @Description: 高风险总入口
 * @author: zhoutg
 * @time: 2018/8/6 9:11
 */
@Component
public class HighRiskProcess {

    @Autowired
    CommonRule commonRule;

    /**
     * 处理业务
     *
     * @param highRiskNeoDTOList
     * @param res
     */
    public void process(List<HighRiskNeoDTO> highRiskNeoDTOList, IndicationDTO res, WordCrfDTO wordCrfDTO) {
        List<BillMsg> highRiskList = new ArrayList<>();
        for (HighRiskNeoDTO highRiskNeoDTO : highRiskNeoDTOList) {
            System.out.println(highRiskNeoDTO);
            String type = highRiskNeoDTO.getType();
            if (highRiskNeoDTO.getIsHighrisk()==true) {
                commonRule.highRisk(highRiskNeoDTO, highRiskList);
            } else {

                List<Item> diag = wordCrfDTO.getDiag();
                List<Lis> lisList = wordCrfDTO.getLis();
                PacsLabel pacsLabel = wordCrfDTO.getPacsLabel();
                VitalLabel vitalLabel = wordCrfDTO.getVitalLabel();
                Integer age1 = wordCrfDTO.getAge();
                // 复杂情况高危手术
                if (TypeEnum.operation.getName().equals(type)) {
                    List<NodeNeoDTO> factor = highRiskNeoDTO.getFactor();
                    for (NodeNeoDTO nodeNeoDTO : factor) {
                        if (TypeEnum.disease.getName().equals(nodeNeoDTO.getTermtype())) {
                            /*String name = nodeNeoDTO.getName();
                            for (Item item : diag) {
                                if (item.getUniqueName().equals(name)) {
                                    BillMsg billMsg = MsgUtil.getComplexOperationMsg( item.getName(), highRiskNeoDTO.getName(),nodeNeoDTO.getTermtype());
                                    res.getHighRiskList().add(billMsg);
                                }
                            }*/
                            BillMsg billMsg = MsgUtil.getComplexOperationMsg( nodeNeoDTO.getVal(), highRiskNeoDTO.getName(),nodeNeoDTO.getTermtype());
                            highRiskList.add(billMsg);
                        } else if (TypeEnum.lis.getName().equals(nodeNeoDTO.getTermtype())) {
                            /*for (Lis lis : lisList) {
                                if (lis.getUniqueName().equals(nodeNeoDTO.getName())) {
                                    Map<String, Object> map = CoreUtil.compareLis(nodeNeoDTO, lis);
                                    if ((Boolean) map.get("flag") == true) {
                                        BillMsg billMsg = MsgUtil.getComplexOperationMsg((String)map.get("msg"), highRiskNeoDTO.getName(), nodeNeoDTO.getTermtype());
                                        res.getHighRiskList().add(billMsg);
                                    }
                                }
                            }*/
                            BillMsg billMsg = MsgUtil.getComplexOperationMsg( nodeNeoDTO.getVal(), highRiskNeoDTO.getName(),nodeNeoDTO.getTermtype());
                            highRiskList.add(billMsg);
                        } else if (TypeEnum.pacs.getName().equals(nodeNeoDTO.getTermtype())) {
                            /*List<Item> pacsDescList = pacsLabel.getRes();
                            //辅检匹配结果
                            for (Item item : pacsDescList) {
                                if (item.getUniqueName().equals(nodeNeoDTO.getVal())) {
                                    BillMsg billMsg = MsgUtil.getComplexOperationMsg(item.getName(), highRiskNeoDTO.getName(), nodeNeoDTO.getTermtype());
                                    res.getHighRiskList().add(billMsg);
                                }
                            }*/
                            BillMsg billMsg = MsgUtil.getComplexOperationMsg( nodeNeoDTO.getVal(), highRiskNeoDTO.getName(),nodeNeoDTO.getTermtype());
                            highRiskList.add(billMsg);
                        } else if (TypeEnum.vital.getName().equals(nodeNeoDTO.getTermtype())){
                            /*Map<String, Object> map = CoreUtil.compareVital(nodeNeoDTO, vitalLabel);
                            if ((Boolean) map.get("flag") == true) {
                                BillMsg commonBillMsg = MsgUtil.getComplexOperationMsg((String)map.get("msg"),highRiskNeoDTO.getName(), nodeNeoDTO.getTermtype());
                                res.getHighRiskList().add(commonBillMsg);
                            }
*/
                            BillMsg billMsg = MsgUtil.getComplexOperationMsg( nodeNeoDTO.getVal(), highRiskNeoDTO.getName(),nodeNeoDTO.getTermtype());
                            highRiskList.add(billMsg);
                        }else if(TypeEnum.age.getName().equals(nodeNeoDTO.getTermtype())){
                            /*Boolean flag = false;
                            if(nodeNeoDTO != null && wordCrfDTO.getAge() != null) {
                                Integer age = wordCrfDTO.getAge();
                                flag = CoreUtil.compareNum(nodeNeoDTO, age);
                            }
                            if (flag) {
                                String message = "年龄" + wordCrfDTO.getAge();
                                BillMsg billMsg = MsgUtil.getComplexOperationMsg(message, highRiskNeoDTO.getName(), nodeNeoDTO.getTermtype());
                                res.getHighRiskList().add(billMsg);
                            }*/
                            BillMsg billMsg = MsgUtil.getComplexOperationMsg( nodeNeoDTO.getVal(), highRiskNeoDTO.getName(),nodeNeoDTO.getTermtype());
                            highRiskList.add(billMsg);
                        }
                    }
                }
            }
        }
        res.setHighRiskList(highRiskList);
    }
}
